BitmapFont

Struct BitmapFont 

pub struct BitmapFont {
    pub glyphs: HashMap<char, BitmapGlyph>,
    pub kerning_table: Option<HashMap<(char, char), f32>>,
    pub ascent: f32,
    pub descent: f32,
    pub line_gap: f32,
    pub padding: u32,
}
Runtime representation of all metadata for a single bitmap font.

Does not own or even reference the bitmap itself.

Fields

glyphs: HashMap<char, BitmapGlyph>

Map of unicode codepoints to glyphs in the font.

kerning_table: Option<HashMap<(char, char), f32>>

Additional kerning to apply as well as that given by BitmapGlyph metrics to a pair of glyphs.

ascent: f32

The highest point that any glyph in the font extends above the baseline. Typically positive.

descent: f32

The lowest point that any glyph in the font extends below the baseline. Typically negative.

line_gap: f32

The gap to leave between the descent of one line and the ascent of the next.

This is of course only a guideline given by the font’s designers.

padding: u32

The distance from the true pixel bounding box of any given glyph to the bounding box given by BitmapGlyph.bitmap_source.