pub struct BitmapGlyph {
pub bitmap_source: Option<SourceRect>,
pub advance_width: f32,
pub left_side_bearing: f32,
pub ascent: f32,
}Expand description
SourceRect and horizontal metrics of a glyph required for text layout.
Fields
bitmap_source: Option<SourceRect>The bounding box of the rendered glyph in the bitmap.
None for whitespace characters.
advance_width: f32The horizontal offset that the origin of the next glyph should be from the origin of this glyph.
left_side_bearing: f32The horizontal offset between the origin of this glyph and the leftmost point of the glyph.
ascent: f32The vertical offset between the origin of this glyph and the baseline. Typhically positive.